Learn R Programming

DoubleExpSeq (version 1.1)

DB.MAPlot: Plots Log-Fold Change versus Log-Concentration for Inclusion/Exclusion Data

Description

M-A Plot

Usage

DB.MAPlot( y, m, groups, contrast=c(1,2), de.tags=NULL,
 col="lightgrey", deCol="red", deCex=0.2,
 xlab="Average Over Groups of log2 Mean Total Count",
 ylab="logFC of Odds Ratio", pch=19, cex=0.2,
 panel.last=grid(col = "red", lwd = 0.2) , ylim = c(-15, 15), ...)

Arguments

y
numeric matrix of inclusion counts.
m
numeric matrix of total counts: inclusion + exclusion.
groups
vector or factor giving the experimental group/condition for each sample/library.
contrast
numeric vector of length 2 specifying which levels of the "groups" factor should be compared.
de.tags
rownames for events identified as being differentially expressed.
col
color given to the points.
deCol
color for the events given in "de.tags".
deCex
cex for the events given in "de.tags".
xlab
x-label of plot
ylab
y-label of plot
pch
pch given to the points.
cex
cex given to the points.
panel.last
an expression to be evaluated after plotting; the default grid() draws a background grid to aid interpretation of the plot.
ylim
y-limits for the plot
...
further arguments passed to plot().

Value

  • A plot to the current device

Details

The total counts are used to determine A, and the log-fold change of the odds ratio is used to determine M. In the case where a group has proportions all 1 or all 0, resulting in an infinite value for M, these points are plotted in orange and away from the main plot. Significant calls made for such events are still colored in red.

Examples

Run this code
data(exon)
results.G1G2 <- DBGLM1( counts, offsets, groups)
de.tags.G1G2 <- rownames(results.G1G2$Sig)
DB.MAPlot(counts, offsets, groups, contrast=c(1,2), de.tags=de.tags.G1G2)

Run the code above in your browser using DataLab